<h1 align="center">SOTAI</h1>

<p align='center'>
<a href="https://pypi.org/project/sotai/"><img src="https://img.shields.io/pypi/v/sotai" /></a>
<a href="https://github.com/SOTAI-Labs/sotai/actions/workflows/tests.yml" ><img src="https://github.com/SOTAI-Labs/sotai/actions/workflows/tests.yml/badge.svg?branch=main" /></a>
</p>

A Library For Interpretable Machine Learning. This library is a PyTorch implementation of modeling techniques found in [Monotonic Calibrated Interpolated Look-Up Tables](https://jmlr.org/papers/volume17/15-243/15-243.pdf).

Installling the package:

```shell
pip install sotai
```

Importing the package:

```python
import sotai
```

## SOTAI Web-App User Documentation

You can find documentation for how to use the hosted web-app at [https://docs.sotai.ai/app](https://docs.sotai.ai/app)

## Contribution Guidelines

See the guide on [contributing](https://github.com/SOTAI-Labs/sotai/blob/main/docs/CONTRIBUTING.md) for full details on how to contribute to the library. For any feature and/or bug requests, visit our [Issues](https://github.com/SOTAI-Labs/sotai/issues).

## Examples

For detailed examples on how to use the library, see [examples](https://github.com/SOTAI-Labs/sotai/tree/main/docs/examples).

## License

[MIT](https://github.com/SOTAI-Labs/sotai/blob/main/LICENSE)
